notes about SQL Server


BLOBData varBinary(MAX)

    means make a BLOB that has no size limit.  The word MAX is a 
    keyword; you can use a number, but it has to be <= 8000.
    max means 2^31-1-2

http://stackoverflow.com/questions/1643627/how-to-insert-a-blob-into-a-database-using-sql-server-management-studio

    shows loading blobs from tsql

http://stackoverflow.com/questions/8240858/how-to-declare-a-blob-in-sql-server


